[svn-commits] tzafrir: trunk r273641 - in /trunk: addons/ apps/ channels/ main/ res/

SVN commits to the Digium repositories svn-commits at lists.digium.com
Fri Jul 2 10:57:13 CDT 2010


Author: tzafrir
Date: Fri Jul  2 10:57:02 2010
New Revision: 273641

URL: http://svnview.digium.com/svn/asterisk?view=rev&rev=273641
Log:
Fix various typos reported by Lintian

(Also fix the typos in the comments)

Modified:
    trunk/addons/chan_mobile.c
    trunk/apps/app_rpt.c
    trunk/apps/app_voicemail.c
    trunk/apps/app_while.c
    trunk/channels/chan_dahdi.c
    trunk/channels/chan_h323.c
    trunk/channels/chan_iax2.c
    trunk/channels/chan_mgcp.c
    trunk/channels/chan_misdn.c
    trunk/channels/chan_sip.c
    trunk/main/fixedjitterbuf.c
    trunk/main/say.c
    trunk/main/utils.c
    trunk/main/xmldoc.c
    trunk/res/res_agi.c

Modified: trunk/addons/chan_mobile.c
URL: http://svnview.digium.com/svn/asterisk/trunk/addons/chan_mobile.c?view=diff&rev=273641&r1=273640&r2=273641
==============================================================================
--- trunk/addons/chan_mobile.c (original)
+++ trunk/addons/chan_mobile.c Fri Jul  2 10:57:02 2010
@@ -1242,7 +1242,7 @@
 	If the end result > 100, and it usually is if we have the problem, set a flag and compensate by shifting the bytes
 	for each subsequent frame during the call.
 
-	If the result is <= 100 then clear the flag so we dont come back in here...
+	If the result is <= 100 then clear the flag so we don't come back in here...
 
 	This seems to work OK....
 

Modified: trunk/apps/app_rpt.c
URL: http://svnview.digium.com/svn/asterisk/trunk/apps/app_rpt.c?view=diff&rev=273641&r1=273640&r2=273641
==============================================================================
--- trunk/apps/app_voicemail.c (original)
+++ trunk/apps/app_voicemail.c Fri Jul  2 10:57:02 2010
@@ -4650,7 +4650,7 @@
 				attach = newtmp;
 				ast_debug(3, "VOLGAIN: Stored at: %s.%s - Level: %.4f - Mailbox: %s\n", attach, format, vmu->volgain, mailbox);
 			} else {
-				ast_log(LOG_WARNING, "Sox failed to reencode %s.%s: %s (have you installed support for all sox file formats?)\n", attach, format,
+				ast_log(LOG_WARNING, "Sox failed to re-encode %s.%s: %s (have you installed support for all sox file formats?)\n", attach, format,
 					soxstatus == 1 ? "Problem with command line options" : "An error occurred during file processing");
 				ast_log(LOG_WARNING, "Voicemail attachment will have no volume gain.\n");
 			}

Modified: trunk/apps/app_while.c
URL: http://svnview.digium.com/svn/asterisk/trunk/apps/app_while.c?view=diff&rev=273641&r1=273640&r2=273641
==============================================================================
--- trunk/apps/app_while.c (original)
+++ trunk/apps/app_while.c Fri Jul  2 10:57:02 2010
@@ -204,7 +204,7 @@
 	}
 
 #if 0
-	/* dont want run away loops if the chan isn't even up
+	/* don't want run away loops if the chan isn't even up
 	   this is up for debate since it slows things down a tad ......
 
 	   Debate is over... this prevents While/EndWhile from working

Modified: trunk/channels/chan_dahdi.c
URL: http://svnview.digium.com/svn/asterisk/trunk/channels/chan_dahdi.c?view=diff&rev=273641&r1=273640&r2=273641
==============================================================================
--- trunk/channels/chan_h323.c (original)
+++ trunk/channels/chan_h323.c Fri Jul  2 10:57:02 2010
@@ -137,7 +137,7 @@
 static int gatekeeper_disable = 1;
 static int gatekeeper_discover = 0;
 static int gkroute = 0;
-/* Find user by alias (h.323 id) is default, alternative is the incomming call's source IP address*/
+/* Find user by alias (h.323 id) is default, alternative is the incoming call's source IP address*/
 static int userbyalias = 1;
 static int acceptAnonymous = 1;
 static unsigned int tos = 0;

Modified: trunk/channels/chan_iax2.c
URL: http://svnview.digium.com/svn/asterisk/trunk/channels/chan_iax2.c?view=diff&rev=273641&r1=273640&r2=273641
==============================================================================
--- trunk/channels/chan_iax2.c (original)
+++ trunk/channels/chan_iax2.c Fri Jul  2 10:57:02 2010
@@ -5808,7 +5808,7 @@
 					ast_debug(1, "predicted timestamp skew (%u) > max (%u), using real ts instead.\n",
 						abs(ms - p->nextpred), MAX_TIMESTAMP_SKEW);
 
-				if (f->samples >= rate) /* check to make sure we dont core dump */
+				if (f->samples >= rate) /* check to make sure we don't core dump */
 				{
 					int diff = ms % (f->samples / rate);
 					if (diff)
@@ -7699,7 +7699,7 @@
 		user = user_unref(user);
 	}
 	if (ast_test_flag64(p, IAX_FORCE_ENCRYPT) && !p->encmethods) { 
-		ast_log(LOG_NOTICE, "Call Terminated, Incomming call is unencrypted while force encrypt is enabled.");
+		ast_log(LOG_NOTICE, "Call Terminated, Incoming call is unencrypted while force encrypt is enabled.");
 		return res;
 	}
 	if (!ast_test_flag(&p->state, IAX_STATE_AUTHENTICATED))

Modified: trunk/channels/chan_mgcp.c
URL: http://svnview.digium.com/svn/asterisk/trunk/channels/chan_mgcp.c?view=diff&rev=273641&r1=273640&r2=273641
==============================================================================
--- trunk/channels/chan_mgcp.c (original)
+++ trunk/channels/chan_mgcp.c Fri Jul  2 10:57:02 2010
@@ -2524,7 +2524,7 @@
 				snprintf(tmp, sizeof(tmp), ", dq-gi:%x", sub->gate->gateid);
 				strncat(local, tmp, sizeof(local) - strlen(local) - 1);
 			} else {
-					/* we still dont have gateid wait */
+					/* we still don't have gateid wait */
 				return 0;
 			}
 		}
@@ -3337,7 +3337,7 @@
 				mgcp_queue_hangup(sub);
 			}
 			transmit_response(sub, "200", req, "OK");
-			/* We dont send NTFY or AUEP to wildcard ep */
+			/* We don't send NTFY or AUEP to wildcard ep */
 			if (strcmp(p->name, p->parent->wcardep) != 0) {
 				transmit_notify_request(sub, "");
 				/* Audit endpoint.

Modified: trunk/channels/chan_misdn.c
URL: http://svnview.digium.com/svn/asterisk/trunk/channels/chan_misdn.c?view=diff&rev=273641&r1=273640&r2=273641
==============================================================================
--- trunk/channels/chan_misdn.c (original)
+++ trunk/channels/chan_misdn.c Fri Jul  2 10:57:02 2010
@@ -2363,7 +2363,7 @@
 		party->TypeOfNumber = misdn_to_PartyNumber_ton_private(id->number_type);
 		break;
 	default:
-		party->TypeOfNumber = 0;/* Dont't care */
+		party->TypeOfNumber = 0;/* Don't care */
 		break;
 	}
 }
@@ -10903,9 +10903,9 @@
 		"    a - Have Asterisk detect DTMF tones on called channel\n"
 		"    c - Make crypted outgoing call, optarg is keyindex\n"
 		"    d - Send display text to called phone, text is the optarg\n"
-		"    e - Perform echo cancelation on this channel,\n"
+		"    e - Perform echo cancellation on this channel,\n"
 		"        takes taps as optarg (32,64,128,256)\n"
-		"   e! - Disable echo cancelation on this channel\n"
+		"   e! - Disable echo cancellation on this channel\n"
 		"    f - Enable fax detection\n"
 		"    h - Make digital outgoing call\n"
 		"   h1 - Make HDLC mode digital outgoing call\n"

Modified: trunk/channels/chan_sip.c
URL: http://svnview.digium.com/svn/asterisk/trunk/channels/chan_sip.c?view=diff&rev=273641&r1=273640&r2=273641
==============================================================================
--- trunk/main/fixedjitterbuf.c (original)
+++ trunk/main/fixedjitterbuf.c Fri Jul  2 10:57:02 2010
@@ -105,7 +105,7 @@
 	/* First copy our config */
 	memcpy(&jb->conf, conf, sizeof(struct fixed_jb_conf));
 
-	/* we dont need the passed config anymore - continue working with the saved one */
+	/* we don't need the passed config anymore - continue working with the saved one */
 	conf = &jb->conf;
 	
 	/* validate the configuration */

Modified: trunk/main/say.c
URL: http://svnview.digium.com/svn/asterisk/trunk/main/say.c?view=diff&rev=273641&r1=273640&r2=273641
==============================================================================
--- trunk/main/say.c (original)
+++ trunk/main/say.c Fri Jul  2 10:57:02 2010
@@ -668,7 +668,7 @@
 					default : options = "m"; /* others are male */
 				}
 			}
-			if ( left > 1 )	{ /* we dont say "one thousand" but only thousand */
+			if ( left > 1 )	{ /* we don't say "one thousand" but only thousand */
 				res = ast_say_number_full_cs(chan, left, ints, language, options, audiofd, ctrlfd);
 				if (res) 
 					return res;
@@ -3997,7 +3997,7 @@
 				}
 				break;
 			case 'H':
-				/* 24-Hour, single digit hours preceeded by "oh" (0) */
+				/* 24-Hour, single digit hours preceded by "oh" (0) */
 				if (tm.tm_hour < 10 && tm.tm_hour > 0) {
 					res = wait_file(chan, ints, "digits/0", lang);
 				}

Modified: trunk/main/utils.c
URL: http://svnview.digium.com/svn/asterisk/trunk/main/utils.c?view=diff&rev=273641&r1=273640&r2=273641
==============================================================================
--- trunk/main/utils.c (original)
+++ trunk/main/utils.c Fri Jul  2 10:57:02 2010
@@ -283,7 +283,7 @@
 			cnt++;
 		}
 	}
-	/* Dont worry about left over bits, they're extra anyway */
+	/* Don't worry about left over bits, they're extra anyway */
 	return cnt;
 }
 

Modified: trunk/main/xmldoc.c
URL: http://svnview.digium.com/svn/asterisk/trunk/main/xmldoc.c?view=diff&rev=273641&r1=273640&r2=273641
==============================================================================
--- trunk/main/xmldoc.c (original)
+++ trunk/main/xmldoc.c Fri Jul  2 10:57:02 2010
@@ -449,7 +449,7 @@
 		}
 	}
 
-	/* remove last spaces (we dont want always to remove the trailing spaces). */
+	/* remove last spaces (we don't want always to remove the trailing spaces). */
 	if (lastspaces) {
 		ast_str_trim_blanks(*output);
 	}

Modified: trunk/res/res_agi.c
URL: http://svnview.digium.com/svn/asterisk/trunk/res/res_agi.c?view=diff&rev=273641&r1=273640&r2=273641
==============================================================================
--- trunk/res/res_agi.c (original)
+++ trunk/res/res_agi.c Fri Jul  2 10:57:02 2010
@@ -371,7 +371,7 @@
 			to the offset without exceeding the end of the file. <replaceable>silence</replaceable> is
 			the number of seconds of silence allowed before the function returns despite the
 			lack of dtmf digits or reaching <replaceable>timeout</replaceable>. <replaceable>silence</replaceable>
-			value must be preceeded by <literal>s=</literal> and is also optional.</para>
+			value must be preceded by <literal>s=</literal> and is also optional.</para>
 		</description>
 	</agi>
 	<agi name="say alpha" language="en_US">




More information about the svn-commits mailing list
--- trunk/apps/app_rpt.c (original)
+++ trunk/apps/app_rpt.c Fri Jul  2 10:57:02 2010
@@ -1534,7 +1534,7 @@
                        l = l->next;
                        continue;
                }
                /* dont send to self */
                if (mylink && (l == mylink))
                {
                        l = l->next;
@@ -1895,7 +1895,7 @@
 	{
 		/* if is not a real link, ignore it */
 		if (l->name[0] == '0') continue;
 		/* dont count our stuff */
 		if (l == mylink) continue;
 		if (mylink && (!strcmp(l->name,mylink->name))) continue;
 		/* figure out mode to report */
@@ -4375,7 +4375,7 @@
 		wait_interval(myrpt, DLY_TELEM, mychannel);
 		l = myrpt->links.next;
 		haslink = 0;
 		/* dont report if a link for this one still on system */
 		if (l != &myrpt->links)
 		{
 			rpt_mutex_lock(&myrpt->lock);
@@ -5223,7 +5223,7 @@
 	{
 	    case UNKEY:
 		/* if any of the following are defined, go ahead and do it,
-		   otherwise, dont bother */
+		   otherwise, don't bother */
 		v1 = (char *) ast_variable_retrieve(myrpt->cfg, myrpt->name, 
 			"unlinkedct");
 		v2 = (char *) ast_variable_retrieve(myrpt->cfg, myrpt->name, 
@@ -6741,7 +6741,7 @@
 					l = l->next;
 					continue;
 				}
 				/* dont send back from where it came */
 				if ((l == mylink) || (!strcmp(l->name,mylink->name)))
 				{
 					l = l->next;
@@ -6772,7 +6772,7 @@
 					l = l->next;
 					continue;
 				}
 				/* dont send back from where it came */
 				if ((l == mylink) || (!strcmp(l->name,mylink->name)))
 				{
 					l = l->next;
@@ -6870,7 +6870,7 @@
 				l = l->next;
 				continue;
 			}
 			/* dont send back from where it came */
 			if ((l == mylink) || (!strcmp(l->name,mylink->name)))
 			{
 				l = l->next;
@@ -6897,7 +6897,7 @@
 				l = l->next;
 				continue;
 			}
 			/* dont send back from where it came */
 			if ((l == mylink) || (!strcmp(l->name,mylink->name)))
 			{
 				l = l->next;
@@ -10147,7 +10147,7 @@
 	/* if decode not active */
 	if (myrpt->dtmfidx == -1)
 	{
-		/* if not lead-in digit, dont worry */
+		/* if not lead-in digit, don't worry */
 		if (c != myrpt->p.funcchar)
 		{
 			if (!myrpt->p.propagate_dtmf)
@@ -12990,7 +12990,7 @@
 	{
 		load_rpt_vars(i,1);
 
-		/* if is a remote, dont start one for it */
+		/* if is a remote, don't start one for it */
 		if (rpt_vars[i].remote)
 		{
 			if(retreive_memory(&rpt_vars[i],"init")){ /* Try to retreive initial memory channel */
@@ -14337,7 +14337,7 @@
 			if (handle_remote_dtmf_digit(myrpt,c,&keyed,0) == -1) break;
 			continue;
 		} else rpt_mutex_unlock(&myrpt->lock);
-		if (who == chan) /* if it was a read from incomming */
+		if (who == chan) /* if it was a read from incoming */
 		{
 			f = ast_read(chan);
 			if (!f)
@@ -1534,7 +1534,7 @@
                        continue;
                }
-               /* dont send to self */
+               /* don't send to self */
                if (mylink && (l == mylink))
                {
@@ -1895,7 +1895,7 @@
 		/* if is not a real link, ignore it */
 		if (l->name[0] == '0') continue;
-		/* dont count our stuff */
+		/* don't count our stuff */
 		if (l == mylink) continue;
 		if (mylink && (!strcmp(l->name,mylink->name))) continue;
@@ -4375,7 +4375,7 @@
 		l = myrpt->links.next;
 		haslink = 0;
-		/* dont report if a link for this one still on system */
+		/* don't report if a link for this one still on system */
 		if (l != &myrpt->links)
 		{
@@ -6741,7 +6741,7 @@
 					continue;
 				}
-				/* dont send back from where it came */
+				/* don't send back from where it came */
 				if ((l == mylink) || (!strcmp(l->name,mylink->name)))
 				{
@@ -6772,7 +6772,7 @@
 					continue;
 				}
-				/* dont send back from where it came */
+				/* don't send back from where it came */
 				if ((l == mylink) || (!strcmp(l->name,mylink->name)))
 				{
@@ -6870,7 +6870,7 @@
 				continue;
 			}
-			/* dont send back from where it came */
+			/* don't send back from where it came */
 			if ((l == mylink) || (!strcmp(l->name,mylink->name)))
 			{
@@ -6897,7 +6897,7 @@
 				continue;
 			}
-			/* dont send back from where it came */
+			/* don't send back from where it came */
 			if ((l == mylink) || (!strcmp(l->name,mylink->name)))
 			{

Modified: trunk/apps/app_voicemail.c
URL: http://svnview.digium.com/svn/asterisk/trunk/apps/app_voicemail.c?view=diff&rev=273641&r1=273640&r2=273641
==============================================================================
--- trunk/channels/chan_dahdi.c (original)
+++ trunk/channels/chan_dahdi.c Fri Jul  2 10:57:02 2010
@@ -1676,7 +1676,7 @@
 	/* We must have a ring by now, so, if configured, lets try to listen for
 	 * distinctive ringing */
 	if ((checkaftercid && distinctiveringaftercid) || !checkaftercid) {
 		/* Clear the current ring data array so we dont have old data in it. */
 		for (receivedRingT = 0; receivedRingT < ARRAY_LEN(ringdata); receivedRingT++)
 			ringdata[receivedRingT] = 0;
 		receivedRingT = 0;
@@ -6408,7 +6408,7 @@
 			p->mate = 1;
 			break;
 		}
-		if (!p->tdd) { /* if we dont have one yet */
+		if (!p->tdd) { /* if we don't have one yet */
 			p->tdd = tdd_new(); /* allocate one */
 		}
 		break;
@@ -6467,10 +6467,10 @@
 	case AST_OPTION_ECHOCAN:
 		cp = (char *) data;
 		if (*cp) {
-			ast_debug(1, "Enabling echo cancelation on %s\n", chan->name);
+			ast_debug(1, "Enabling echo cancellation on %s\n", chan->name);
 			dahdi_enable_ec(p);
 		} else {
-			ast_debug(1, "Disabling echo cancelation on %s\n", chan->name);
+			ast_debug(1, "Disabling echo cancellation on %s\n", chan->name);
 			dahdi_disable_ec(p);
 		}
 		break;
@@ -8364,7 +8364,7 @@
 
 	/* Hang up if we don't really exist */
 	if (idx < 0)	{
-		ast_log(LOG_WARNING, "We dont exist?\n");
+		ast_log(LOG_WARNING, "We don't exist?\n");
 		ast_mutex_unlock(&p->lock);
 		return NULL;
 	}
@@ -9962,7 +9962,7 @@
 					if (p->usedistinctiveringdetection) {
 						len = 0;
 						distMatches = 0;
 						/* Clear the current ring data array so we dont have old data in it. */
 						for (receivedRingT = 0; receivedRingT < ARRAY_LEN(curRingData); receivedRingT++)
 							curRingData[receivedRingT] = 0;
 						receivedRingT = 0;
@@ -10112,7 +10112,7 @@
 					samples = 0;
 					len = 0;
 					distMatches = 0;
 					/* Clear the current ring data array so we dont have old data in it. */
 					for (receivedRingT = 0; receivedRingT < ARRAY_LEN(curRingData); receivedRingT++)
 						curRingData[receivedRingT] = 0;
 					receivedRingT = 0;
@@ -10198,7 +10198,7 @@
 						ast_debug(1, "CallerID number: %s, name: %s, flags=%d\n", number, name, flags);
 					}
 					if (distinctiveringaftercid == 1) {
 						/* Clear the current ring data array so we dont have old data in it. */
 						for (receivedRingT = 0; receivedRingT < 3; receivedRingT++) {
 							curRingData[receivedRingT] = 0;
 						}
@@ -12022,7 +12022,7 @@
 				p.debouncetime = conf->timing.debouncetime;
 		}
 
 		/* dont set parms on a pseudo-channel */
 		if (tmp->subs[SUB_REAL].dfd >= 0)
 		{
 			res = ioctl(tmp->subs[SUB_REAL].dfd, DAHDI_SET_PARAMS, &p);
@@ -17502,7 +17502,7 @@
 		ast_log(LOG_WARNING, "Huh?  I don't exist?\n");
 		return -1;
 	}
-	if (!text[0]) return(0); /* if nothing to send, dont */
+	if (!text[0]) return(0); /* if nothing to send, don't */
 	if ((!p->tdd) && (!p->mate)) return(0);  /* if not in TDD mode, just return */
 	if (p->mate)
 		buf = ast_malloc(((strlen(text) + 1) * ASCII_BYTES_PER_CHAR) + END_SILENCE_LEN + HEADER_LEN);
@@ -1676,7 +1676,7 @@
 	 * distinctive ringing */
 	if ((checkaftercid && distinctiveringaftercid) || !checkaftercid) {
-		/* Clear the current ring data array so we dont have old data in it. */
+		/* Clear the current ring data array so we don't have old data in it. */
 		for (receivedRingT = 0; receivedRingT < ARRAY_LEN(ringdata); receivedRingT++)
 			ringdata[receivedRingT] = 0;
@@ -9962,7 +9962,7 @@
 						len = 0;
 						distMatches = 0;
-						/* Clear the current ring data array so we dont have old data in it. */
+						/* Clear the current ring data array so we don't have old data in it. */
 						for (receivedRingT = 0; receivedRingT < ARRAY_LEN(curRingData); receivedRingT++)
 							curRingData[receivedRingT] = 0;
@@ -10112,7 +10112,7 @@
 					len = 0;
 					distMatches = 0;
-					/* Clear the current ring data array so we dont have old data in it. */
+					/* Clear the current ring data array so we don't have old data in it. */
 					for (receivedRingT = 0; receivedRingT < ARRAY_LEN(curRingData); receivedRingT++)
 						curRingData[receivedRingT] = 0;
@@ -10198,7 +10198,7 @@
 					}
 					if (distinctiveringaftercid == 1) {
-						/* Clear the current ring data array so we dont have old data in it. */
+						/* Clear the current ring data array so we don't have old data in it. */
 						for (receivedRingT = 0; receivedRingT < 3; receivedRingT++) {
 							curRingData[receivedRingT] = 0;
@@ -12022,7 +12022,7 @@
 		}
 
-		/* dont set parms on a pseudo-channel */
+		/* don't set parms on a pseudo-channel */
 		if (tmp->subs[SUB_REAL].dfd >= 0)
 		{

Modified: trunk/channels/chan_h323.c
URL: http://svnview.digium.com/svn/asterisk/trunk/channels/chan_h323.c?view=diff&rev=273641&r1=273640&r2=273641
==============================================================================
--- trunk/channels/chan_sip.c (original)
+++ trunk/channels/chan_sip.c Fri Jul  2 10:57:02 2010
@@ -7125,7 +7125,7 @@
 	/* We do not respond to responses for dialogs that we don't know about, we just drop
 	   the session quickly */
 	if (intended_method == SIP_RESPONSE)
-		ast_debug(2, "That's odd...  Got a response on a call we dont know about. Callid %s\n", callid ? callid : "<unknown>");
+		ast_debug(2, "That's odd...  Got a response on a call we don't know about. Callid %s\n", callid ? callid : "<unknown>");
 
 	return NULL;
 }
@@ -9709,7 +9709,7 @@
 	if (p->rtp) {
 		struct ast_codec_pref *pref = &ast_rtp_instance_get_codecs(p->rtp)->pref;
 		fmt = ast_codec_pref_getsize(pref, codec);
-	} else /* I dont see how you couldn't have p->rtp, but good to check for and error out if not there like earlier code */
+	} else /* I don't see how you couldn't have p->rtp, but good to check for and error out if not there like earlier code */
 		return;
 	ast_str_append(m_buf, 0, " %d", rtp_code);
 	ast_str_append(a_buf, 0, "a=rtpmap:%d %s/%d\r\n", rtp_code,
@@ -12882,7 +12882,7 @@
 		return AUTH_CHALLENGE_SENT;
 	}
 	if (good_response) {
-		append_history(p, "AuthOK", "Auth challenge succesful for %s", username);
+		append_history(p, "AuthOK", "Auth challenge successful for %s", username);
 		return AUTH_SUCCESSFUL;
 	}
 
@@ -18689,7 +18689,7 @@
 		}
 		
 		r->regstate = REG_STATE_REGISTERED;
-		r->regtime = ast_tvnow();		/* Reset time of last succesful registration */
+		r->regtime = ast_tvnow();		/* Reset time of last successful registration */
 		manager_event(EVENT_FLAG_SYSTEM, "Registry", "ChannelType: SIP\r\nDomain: %s\r\nStatus: %s\r\n", r->hostname, regstate2str(r->regstate));
 		r->regattempts = 0;
 		ast_debug(1, "Registration successful\n");
@@ -19187,7 +19187,7 @@
 					}
 				}
 			} else
-				ast_log(LOG_NOTICE, "Dont know how to handle a %d %s response from %s\n", resp, rest, p->owner ? p->owner->name : ast_inet_ntoa(p->sa.sin_addr));
+				ast_log(LOG_NOTICE, "Don't know how to handle a %d %s response from %s\n", resp, rest, p->owner ? p->owner->name : ast_inet_ntoa(p->sa.sin_addr));
 		}
 	} else {	
 		/* Responses to OUTGOING SIP requests on INCOMING calls
@@ -20742,7 +20742,7 @@
 			}
 		}
 
 		/* We have a succesful authentication, process the SDP portion if there is one */
 		if (find_sdp(req)) {
 			if (process_sdp(p, req, SDP_T38_INITIATE)) {
 				/* Unacceptable codecs */
@@ -20742,7 +20742,7 @@
 		}
 
-		/* We have a succesful authentication, process the SDP portion if there is one */
+		/* We have a successful authentication, process the SDP portion if there is one */
 		if (find_sdp(req)) {
 			if (process_sdp(p, req, SDP_T38_INITIATE)) {

Modified: trunk/main/fixedjitterbuf.c
URL: http://svnview.digium.com/svn/asterisk/trunk/main/fixedjitterbuf.c?view=diff&rev=273641&r1=273640&r2=273641
==============================================================================